@@ -1,5 +1,6 @@
 package RPC::Object::Common;
 use base qw(Exporter);
+use constant FIND_INSTANCE => '_rpc_object_find_instance';
 use constant RESPONSE_ERROR => 'e';
 use constant RESPONSE_NORMAL => 'n';
 use constant WANT_LIST => 'l';
@@ -7,7 +8,8 @@ use constant WANT_SCALAR => 's';
 use strict;
 use warnings;
 
-our @EXPORT = qw(RESPONSE_ERROR
+our @EXPORT = qw(FIND_INSTANCE
+                 RESPONSE_ERROR
                  RESPONSE_NORMAL
                  WANT_LIST
                  WANT_SCALAR
